# Table of Contents

- [use-cases](<./use-cases.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Use Cases](<./Use-Cases.md>)
  - [Was this page helpful?](<./Use-Cases/Was-this-page-helpful.md>)
